-- ============================================================================
-- == HalonaTools - A collection of tools required by members of the         ==
-- ==               Alliance PVE Raiding Guild "Halona" of the Silvermoon EU ==
-- ==               Realm of Blizzard Entertainment's "World of Warcraft"    ==
-- ==               MMORPG. These tools are provided in the form of an addon ==
-- ==               that supplements those controls found within the default ==
-- ==               UI provided by the game and those provided by the        ==
-- ==               authors of other third-party UI addons.                  ==
-- ==                                                                        ==
-- ==               This addon is based upon the Ace3 library framework and  ==
-- ==               additionally supports other standards such as the LDB    ==
-- ==               (aka: LibDataBroker) method for enabling integration of  ==
-- ==               this addon with a wide-range of LDB-compatible "Display" ==
-- ==               addons.                                                  ==
-- ==                                                                        ==
-- ==               Development of this addon is managed via the resources   ==
-- ==               provided by the WoWAce community as follows.             ==
-- ==                                                                        ==
-- ==               Home-Page: http://www.wowace.com/projects/HalonaTools    ==
-- ==               SVN......: svn://svn.wowace.com/projects/halonatools     ==
-- ==               Download.: http://wow.curse.com/addons/wow/HalonaTools   ==
-- ==               Author...: broliant@broliant.com                         ==
-- ============================================================================

HalonaTools   = LibStub("AceAddon-3.0"):NewAddon("HalonaTools", "AceConsole-3.0", "AceEvent-3.0")
local L       = LibStub("AceLocale-3.0"):GetLocale("HalonaTools")

-- ============================================================================
-- == OnInitialize()                                                         ==
-- ==                                                                        ==
-- == This function is called when the addon is initialised.                 ==
-- ============================================================================

function HalonaTools:OnInitialize() 
end

-- ============================================================================
-- == OnEnable()                                                             ==
-- ==                                                                        ==
-- == This function is called when the addon is enabled.                     ==
-- ============================================================================

function HalonaTools:OnEnable()
end

-- ============================================================================
-- == OnEnable()                                                             ==
-- ==                                                                        ==
-- == This function is called when the addon is disabled.                    ==
-- ============================================================================

function HalonaTools:OnDisable()
end

-- ============================================================================
-- == BeginRaidInvitationPeriod(characterName)                               ==
-- ==                                                                        ==
-- == This function handles the initiation of the raid invitation period.    ==
-- == Specifically, it sends an announcement to the GUILD chat channel and   ==
-- == updates the GMOTD to indicate that the period is in effect and to      ==
-- == advise members who to contact for an invitation to the raid.           ==
-- ============================================================================

function HalonaTools:BeginRaidInvitationPeriod(characterName)
  
  local gmotdText = string.gsub(L["ht-raid-invites-begin-gmotd-01"], "CHARACTER_NAME", characterName)
  local gchatText = string.gsub(L["ht-raid-invites-begin-gchat-01"], "CHARACTER_NAME", characterName)
  
  if HTCommon:IsOfficer(characterName) then
    GuildSetMOTD(gmotdText)
  end
  
  HTConsole:SendTitleBar("GUILD")
  HTConsole:SendWrappedMessage(L["ht-raid-invites-begin-title-01"], "GUILD")
  HTConsole:SendTitleBar("GUILD")
  HTConsole:SendWrappedMessage(gchatText, "GUILD")
  HTConsole:SendTitleBar("GUILD")
  
end

-- ============================================================================
-- == BeginRaidSession(characterName)                                        ==
-- ==                                                                        ==
-- == This function handles the initiation of the raid session.              ==
-- == Specifically, it sends an announcement to the GUILD chat channel and   ==
-- == updates the GMOTD to indicate that the period is in effect and to      ==
-- == advise members who to contact for an invitation to the raid.           ==
-- ============================================================================

function HalonaTools:BeginRaidSession(characterName)
  
  local gmotdText = string.gsub(L["ht-raid-session-begin-gmotd-01"], "CHARACTER_NAME", characterName)
  local gchatText = string.gsub(L["ht-raid-session-begin-gchat-01"], "CHARACTER_NAME", characterName)
  
  if HTCommon:IsOfficer(characterName) then
    GuildSetMOTD(gmotdText)
  end
  
  HTConsole:SendTitleBar("GUILD")
  HTConsole:SendWrappedMessage(L["ht-raid-session-begin-title-01"], "GUILD")
  HTConsole:SendTitleBar("GUILD")
  HTConsole:SendWrappedMessage(gchatText, "GUILD")
  HTConsole:SendTitleBar("GUILD")
  
end

-- ============================================================================
-- == EndRaidSession(characterName)                                          ==
-- ==                                                                        ==
-- == This function handles the termination of the raid session.             ==
-- == Specifically, it sends an announcement to the GUILD chat channel and   ==
-- == updates the GMOTD to indicate that the period is in effect and to      ==
-- == advise members who to contact for an invitation to the raid.           ==
-- ============================================================================

function HalonaTools:EndRaidSession(characterName)
  
  local gmotdText = string.gsub(L["ht-raid-session-end-gmotd-01"], "CHARACTER_NAME", characterName)
  local gchatText = string.gsub(L["ht-raid-session-end-gchat-01"], "CHARACTER_NAME", characterName)
  
  if HTCommon:IsOfficer(characterName) then
    GuildSetMOTD(gmotdText)
  end
  
  HTConsole:SendTitleBar("GUILD")
  HTConsole:SendWrappedMessage(L["ht-raid-session-end-title-01"], "GUILD")
  HTConsole:SendTitleBar("GUILD")
  HTConsole:SendWrappedMessage(gchatText, "GUILD")
  HTConsole:SendTitleBar("GUILD")
  
end

-- ============================================================================
-- == CreateDBMTimer(duration, name, broadcastToRaid)                        ==
-- ==                                                                        ==
-- == This function creates a new DBM (Deadly Boss-Mods) timer where the     ==
-- == duration, name and whether the timer is to be broadcast to the raid    ==
-- == are provided as parameters.                                            ==
-- ============================================================================

function HalonaTools:CreateDBMTimer(duration, name, broadcastToRaid)

  DBM:CreatePizzaTimer(duration, name, broadcastToRaid)
  
end















































